ash_candle_chart_core library

Core logic for Ash Candle Chart, including data structures and compute engine.

Classes

Annotation
Base class for all drawing annotations.
AnnotationDocument
A document containing a collection of annotations.
AnnotationPoint
Represents a point in the chart coordinates.
Candle
Represents a single OHLCV candle in a financial chart.
ChartFrame
Represents a complete snapshot of the chart state for a single frame.
ComputeRequest
Base class for messages sent to the isolate.
ComputeResponse
Base class for messages received from the isolate.
ControlMessage
Internal message to control the isolate worker.
CrosshairState
Represents the state of the crosshair in the chart.
IsolatePool
A pool of Isolates to perform heavy computations off the UI thread.
LiquidationArea
Represents a liquidation zone on the chart.
OrderBook
Represents the real-time state of an order book.
OrderBookEntry
Represents an entry in the order book.
Series
An immutable columnar storage for financial series data.
TradeOverlay
Represents a trade-related overlay on the chart.
TradeOverlayDocument
A collection of trade overlays.
Viewport
Represents the visible range and state of the chart.
VolumeProfile
Represents the volume profile for a specific range.
VolumeProfileBin
Represents a single bin in a volume profile.

Extensions

AnnotationDocumentPatterns on AnnotationDocument
Adds pattern-matching-related methods to AnnotationDocument.
AnnotationPatterns on Annotation
Adds pattern-matching-related methods to Annotation.
AnnotationPointPatterns on AnnotationPoint
Adds pattern-matching-related methods to AnnotationPoint.
CandlePatterns on Candle
Adds pattern-matching-related methods to Candle.
ChartFramePatterns on ChartFrame
Adds pattern-matching-related methods to ChartFrame.
ComputeRequestPatterns on ComputeRequest
Adds pattern-matching-related methods to ComputeRequest.
ComputeResponsePatterns on ComputeResponse
Adds pattern-matching-related methods to ComputeResponse.
ControlMessagePatterns on ControlMessage
Adds pattern-matching-related methods to ControlMessage.
CrosshairStatePatterns on CrosshairState
Adds pattern-matching-related methods to CrosshairState.
LiquidationAreaPatterns on LiquidationArea
Adds pattern-matching-related methods to LiquidationArea.
OrderBookEntryPatterns on OrderBookEntry
Adds pattern-matching-related methods to OrderBookEntry.
OrderBookPatterns on OrderBook
Adds pattern-matching-related methods to OrderBook.
TradeOverlayDocumentPatterns on TradeOverlayDocument
Adds pattern-matching-related methods to TradeOverlayDocument.
TradeOverlayPatterns on TradeOverlay
Adds pattern-matching-related methods to TradeOverlay.
ViewportPatterns on Viewport
Adds pattern-matching-related methods to Viewport.
VolumeProfileBinPatterns on VolumeProfileBin
Adds pattern-matching-related methods to VolumeProfileBin.
VolumeProfileCalculator on Series
Extension to calculate VolumeProfile from a Series.
VolumeProfilePatterns on VolumeProfile
Adds pattern-matching-related methods to VolumeProfile.

Typedefs

RegistryProvider = IndicatorRegistry Function()
A function that returns an IndicatorRegistry. MUST be a top-level or static function.
WorkerHandler = FutureOr<Object?> Function(String method, Object? payload)
Function signature for the task handler running in the worker isolate.

Exceptions / Errors

ChartFrameDeserializationException
Exception thrown when ChartFrame binary deserialization fails.
OperationCanceledException
Exception thrown when a computation is canceled.
SeriesDeserializationException
Exception thrown when binary deserialization fails.